LinuxInAppBrowserCreationParams class

Constructors

LinuxInAppBrowserCreationParams({ContextMenu? contextMenu, PlatformPullToRefreshController? pullToRefreshController, PlatformFindInteractionController? findInteractionController, UnmodifiableListView<UserScript>? initialUserScripts, int? windowId, PlatformWebViewEnvironment? webViewEnvironment})
const
LinuxInAppBrowserCreationParams.fromPlatformInAppBrowserCreationParams(PlatformInAppBrowserCreationParams params)

Properties

contextMenu → ContextMenu?
Context menu used by the browser. It should be set before opening the browser.
finalinherited
findInteractionController → PlatformFindInteractionController?
Represents the find interaction feature controller.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initialUserScripts UnmodifiableListView<UserScript>?
Initial list of user scripts to be loaded at start or end of a page loading.
finalinherited
pullToRefreshController → PlatformPullToRefreshController?
Represents the pull-to-refresh feature controller.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webViewEnvironment → PlatformWebViewEnvironment?
Used to create the PlatformInAppBrowser using the specified environment.
finalinherited
windowId int?
The window id of a CreateWindowAction.windowId.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited